/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.loclib;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Properties;

/**
 * Centrally stores all loclib configuration.
 * 
 * @author faerber
 */
public abstract class Configuration {
	private static Properties properties;
	
	/**
	 * Loads the properties file.
	 */
	private static void init() {
		try {
			properties = new Properties();
			properties.load(Configuration.class.getResource("/loclib.properties").openStream());
		} catch (FileNotFoundException fnfe) {
			// ignore - loclib.properties does not need to exist
		} catch (IOException ioe) {
		}
	}
	
	/**
	 * @see java.util.Properties#getProperty
	 */
	public static String getProperty(String key, String defaultValue) {
		if (properties == null) init();
		return properties.getProperty(key, defaultValue);
	}
	
	/**
	 * @see java.util.Properties#getProperty
	 */
	public static String getProperty(String key) {
		if (properties == null) init();
		return properties.getProperty(key);
	}
}
