/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.loclib;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.InputStreamReader;
import java.io.IOException;

/**
 * A base class for file recorder applications.
 * 
 * @author faerber
 */
public abstract class FileRecorder {
	
	private File file; // the output file
	private long duration = 0; // the duration for recording in milliseconds
	private long startTimestamp; // starting point of message receiving
	
	protected FileRecorder(File file, long duration) throws FileNotFoundException {
		if (duration < 0)
			throw new IllegalArgumentException("Invalid duration. Must be greater or equal zero.");
		this.file = file;
		this.duration = duration;
	}
	
	protected void start() {
		startTimestamp = System.currentTimeMillis();
		if (duration == 0) {
			try {
				BufferedReader r = new BufferedReader(new InputStreamReader(System.in));
				r.readLine();
				r.close();
			} catch (IOException ioe) {
			} finally {
				stop();
			}
		}
	}
	
	protected void stop() {
	}
	
	protected long getTimeRemaining() {
		return startTimestamp + duration - System.currentTimeMillis();
	}
	
	protected boolean isFinished() {
		if (duration == 0)
			return false;
		return (System.currentTimeMillis() > (startTimestamp + duration));
	}
}
