/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.loclib;

/**
 * Base class for our I/O handlers.
 * 
 * @author faerber
 */
public abstract class InputOutputHandler implements Runnable {
	private Thread worker;
	
	/**
	 * Constructs a new <code>InputOutputHandlerBase</code> instance.
	 */
	protected InputOutputHandler() {
	}
	
	/**
	 * Starts processing.
	 */
	public void start() {
		worker = new Thread(this);
		worker.start();
	}
	
	/**
	 * Does the actual processing.
	 */
	public abstract void run();
	
	/**
	 * Frees all resources.
	 */
	public void close() {
		if ((worker != null) && worker.isAlive() && (worker != Thread.currentThread())) {
			try {
				worker.join();
			} catch (InterruptedException ex) {
			}
		}
	}
}
