/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.loclib;

import javax.microedition.location.*;

/**
 * <code>Location</code> data.
 * 
 * @author faerber
 */
abstract class LocationData extends Location {
	
	protected QualifiedCoordinates coordinates = null;
	protected AddressInfo addressInfo = null;
	protected float course = Float.NaN;
	protected int locationMethod = 0;
	protected float speed = Float.NaN;
	protected long timeStamp = 0;
	protected boolean isValid = true;
	
	/**
	 * Constructs a new <code>GpsLocation</code> instance based on qualified coordinates.
	 * 
	 * @param coordinates	the qualified GPS coordinates
	 */
	protected LocationData(int method, QualifiedCoordinates coordinates, float speed, float course, long timestamp) {
		this.locationMethod = method;
		this.coordinates = coordinates;
		this.speed = speed;
		this.course = course;
		this.timeStamp = timestamp;
		isValid = (coordinates != null);
	}
	
	public AddressInfo getAddressInfo() {
		return addressInfo;
	}
	
	public float getCourse() {
		return this.course;
	}
	
	public int getLocationMethod() {
		return this.locationMethod;
	}
	
	public float getSpeed() {
		return this.speed;
	}
	
	public long getTimestamp() {
		return this.timeStamp;
	}
	
	public QualifiedCoordinates getQualifiedCoordinates() {
		return this.coordinates;
	}
	
	public boolean isValid() {
		return this.isValid;
	}

}
