/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.loclib;

import java.util.HashMap;
import javax.microedition.location.*;

/**
 * A <code>LocationProvider</code> base on the Sensor Fusion algorithm.
 * Currently based on <code>GpsBluetoothLocationProvider</code>.
 * 
 * @author faerber
 */
public class SensorFusionLocationProvider extends LocationProvider {
	
	private Criteria criteria;
	private GpsBluetoothLocationProvider gbProv;
	
	private static HashMap instances = new HashMap();
	
	public static LocationProvider getInstance(Criteria criteria) throws LocationException {
		if (criteria == null)
			criteria = new Criteria();
		if (instances.containsKey(criteria)) {
			return (SensorFusionLocationProvider) instances.get(criteria);
		} else {
			SensorFusionLocationProvider prov = new SensorFusionLocationProvider(criteria);
			instances.put(criteria, prov);
			return prov;
		}
	}
	
	private SensorFusionLocationProvider(Criteria criteria) throws LocationException {
		this.criteria = criteria;
		gbProv = (GpsBluetoothLocationProvider) GpsBluetoothLocationProvider.getInstance(criteria);
	}
	
	public int getState() {
		return gbProv.getState();
	}
	
	public void setLocationListener(LocationListener listener, int interval, int timeout, int maxAge) {
		gbProv.setLocationListener(listener, interval, timeout, maxAge);
	}
	
	public Location getLocation(int timeout) throws LocationException, InterruptedException {
		return gbProv.getLocation(timeout);
	}
	
	public void reset() {
		gbProv.reset();
	}
}
