/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.loclib;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;

/**
 * A base class for file recorders using text files.
 * 
 * @author faerber
 */
public abstract class TextFileRecorder extends FileRecorder {
	
	protected BufferedWriter writer; // the writer
	
	protected TextFileRecorder(File file, long duration) throws FileNotFoundException {
		super(file, duration);
		writer = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file)));
	}
	
	protected void stop() {
		try {
			writer.flush();
			writer.close();
		} catch (IOException ex) {
			System.err.println(ex.getLocalizedMessage());
		}
	}
}
