/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.loclib.apps.spbm;

import java.io.FileWriter;
import java.io.IOException;
import java.io.PrintWriter;

import javax.microedition.location.Criteria;
import javax.microedition.location.Location;
import javax.microedition.location.LocationListener;
import javax.microedition.location.LocationProvider;
import javax.microedition.location.QualifiedCoordinates;

import org.pi4.loclib.GpsLocationProvider;

/**
 * Maps GPS positions to square and feeds them into /proc/spbm/pos
 * 
 * @author transier
 * 
 */
public class SpbmLocationConverter implements LocationListener {

	final private double OFFSET_X; // = 49.3;
	final private double OFFSET_Y; // = 8.4;
	final private double STEP_X; // = 0.0001;
	final private double STEP_Y; // = 0.0001;

	public SpbmLocationConverter(double offsetX, double offsetY, double stepX, double stepY) {
		try {
			Criteria criteria = new Criteria();
			LocationProvider lp = new GpsLocationProvider(criteria);
			lp.setLocationListener(this, 1, 1, 1);
		} catch (IOException le) {
			System.out.println(le.getLocalizedMessage());
		}
		OFFSET_X = offsetX;
		OFFSET_Y = offsetY;
		STEP_X = stepX;
		STEP_Y = stepY;
	}

	public void locationUpdated(LocationProvider provider, Location loc) {
		QualifiedCoordinates coord = loc.getQualifiedCoordinates();

		boolean error = false;

		int x = (int) ((coord.getLatitude() - OFFSET_X) / STEP_X);
		int y = (int) ((coord.getLongitude() - OFFSET_Y) / STEP_Y);

		if (x < 0) {
			System.out.println("X coordinate below lower bound");
			error = true;
		}
		if (y < 0) {
			System.out.println("Y coordinate below lower bound");
			error = true;
		}
		if (x > 0xffff) {
			System.out.println("X coordinate beyond upper bound");
			error = true;
		}
		if (y > 0xffff) {
			System.out.println("Y coordinate beyond upper bound");
			error = true;
		}

		if (!error) {
			// System.out.println("echo '0" + Integer.toHexString(x) + " 0" +
			// Integer.toHexString(y) + "' > /proc/spbm/pos");
			try {
				PrintWriter pw = new PrintWriter(new FileWriter("/proc/spbm/pos"), true);
				pw.println("0" + Integer.toHexString(x) + " 0" + Integer.toHexString(y));
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		} else {
			System.out.println("Latitude: " + coord.getLatitude());
			System.out.println("Longitude: " + coord.getLongitude());
			System.out.println("Mapped to x: " + x);
			System.out.println("Mapped to y: " + y);
		}
	}

	public void providerStateChanged(LocationProvider provider, int newState) {
		System.out.println("Location provider " + provider + " new state: " + newState);
	}

	public static void main(String[] args) {
		if (args.length != 4) {
			System.out
					.println("usage: java org.pi4.loclib.apps.spbm.SpbmLocationProvider OffsetLatitude OffsetLongitude StepWidthX StepWidthY");
		}
		new SpbmLocationConverter(Double.parseDouble(args[0]), Double.parseDouble(args[1]),
				Double.parseDouble(args[2]), Double.parseDouble(args[3]));
	}
}
