/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.nmea0183;

/**
 * Stores information about a date (day, month, year).
 * 
 * @author abiskop
 */
public class Date {

	private int day;
	private int month;
	private int year;

	/**
	 * Constructor for <code>Date</code>.
	 * 
	 * @param day dd
	 * @param month mm
	 * @param year yy
	 */
	public Date(int day, int month, int year) {
		this.day = day;
		this.month = month;
		this.year = year;
	}
	
	/**
	 * Returns the day.
	 * 
	 * @return day  
	 */
	public int getDay() {
		return this.day;
	}
	
	/**
	 * Returns the month.
	 * 
	 * @return month
	 */
	public int getMonth() {
		return this.month;
	}
	
	/**
	 * Returns the year. This does not include the century.
	 * 
	 * @return year
	 */
	public int getYear() {
		return this.year;
	}
	
	/**
	 * Returns a NMEA sentence compliant <code>String</code> representation of this <code>Date</code> object.
	 * 
	 * <p>ddmmyy</p>
	 * 
	 * @return stringRepresentation 
	 */
	public String toString() {
		StringBuffer sb = new StringBuffer();
		if (this.day < 10) sb.append('0');
		sb.append(this.day);
		if (this.month < 10) sb.append('0');
		sb.append(this.month);
		if (this.year < 10) sb.append('0');
		sb.append(this.year);
		return sb.toString();
	}
	
	/**
	 * Returns a detailed <code>String</code> representation of this <code>Date</code> object.
	 * 
	 * <p>dd.mm.yy</p>
	 * 
	 * @return stringRepresentation
	 */
	public String dump() {
		StringBuffer sb = new StringBuffer();
		if(this.day < 10) sb.append('0');
		sb.append(this.day);
		sb.append('.');
		if(this.month < 10) sb.append('0');
		sb.append('.');
		sb.append(this.year);
		return sb.toString();
	}
}
