/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

/**
 * Handles a StateChange of the InputOutputHandler.
 * 
 * @author king
 */
 
package org.pi4.nmea0183;

public interface StateChangeListener {
	
	// States
	/**
	 * Available.
	 * 
	 * @see javax.microedition.location.LocationProvider.AVAILABLE
	 */
	public final int AVAILABLE = 1;
	
	/**
	 * Out of service.
	 * 
	 * @see javax.microedition.location.LocationProvider.OUT_OF_SERVICE
	 */
	public final int OUT_OF_SERVICE = 3;
	
	/**
	 * Temporarily unavailable.
	 * 
	 * @see javax.microedition.location.LocationProvider.TEMPORARILY_UNAVAILABLE
	 */
	public final int TEMPORARILY_UNAVAILABLE = 2;
	
	
	/**
	 * Called when the state of the NMEA-0183 I/O handler has changed.
	 * 
	 * @param newState	one of the state enumeration values of this interface
	 */
	public void stateChanged(int newState);
}
