/*
 * This file is part of Loclib.
 *
 * Loclib is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * Loclib is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Loclib; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package org.pi4.nmea0183;

/**
 * Stores information about a time stamp (hours, minutes, seconds).
 * 
 * @author abiskop
 */
public class TimeStamp {
	private int hours;
	private int minutes;
	private int seconds;
	private int milliseconds;

	/**
	 * Constructor for <code>TimeStamp</code>.
	 * 
	 * @param hours
	 * @param minutes
	 * @param seconds
	 * @param milliseconds
	 */
	public TimeStamp(int hours, int minutes, int seconds, int milliseconds) {
		this.hours = hours;
		this.minutes = minutes;
		this.seconds = seconds;
		this.milliseconds = milliseconds;
	}
	
	/**
	 * Returns the hours.
	 * 
	 * @return hours
	 */
	public int getHours() {
		return this.hours;
	}
	
	/**
	 * Returns the minutes.
	 * 
	 * @return minutes
	 */
	public int getMinutes() {	
		return this.minutes;
	}
	
	/**
	 * Returns the seconds.
	 * 
	 * @return seconds
	 */
	public int getSeconds() {
		return this.seconds;
	}
	
	/**
	 * Returns the milliseconds
	 * @return	milliseconds
	 */
	public int getMilliseconds() {
		return this.milliseconds;
	}
	
	/**
	 * Returns a detailed <code>String</code> representation of this <code>TimeStamp</code> object.<p>
	 * 
	 * hh:mm:ss.msms<p>
	 * 
	 * @return stringRepresentation 
	 */
	public String dump() {
		StringBuffer sb = new StringBuffer();
		if(this.hours < 10) sb.append('0');
		sb.append(this.hours);
		sb.append(':');
		if(this.minutes < 10) sb.append('0');
		sb.append(this.minutes);
		sb.append(':');
		if(this.seconds < 10) sb.append('0');
		sb.append(this.seconds);
		sb.append('.');
		if (this.milliseconds < 100) sb.append('0');
		if (this.milliseconds < 10) sb.append('0');
		sb.append(this.milliseconds);
		
		return sb.toString();
	}
	
	/**
	 * Returns a NMEA sentence compliant <code>String</code> representation of this <code>TimeStamp</code> object.<p>
	 * 
	 * hhmmss<p>
	 * 
	 * @return stringRepresentation
	 */
	public String toString() {
		StringBuffer sb = new StringBuffer();
		if (this.hours < 10) sb.append('0');
		sb.append(this.hours);
		if (this.minutes < 10) sb.append('0');
		sb.append(this.minutes);
		if (this.seconds < 10) sb.append('0');
		sb.append(this.seconds);
		sb.append('.');
		if (this.milliseconds < 100)
			sb.append('0');
		if (this.milliseconds < 10)
			sb.append('0');
		sb.append(this.milliseconds);
		return sb.toString();
	}
}
